#########################################################################
##  BOOT.R
##  
##  This is a R program, written by Bruce E. Hansen.
##  It replicates Table 6 from my paper
##  "The Grid Bootstrap and the Autoregressive Model".
##  
##  The procedure grid_boot is designed to implement the grid bootstrap 
##  for general AR models.  
##  
##  PROC GRID_BOOT
##  Format: 	
##  	out <- grid_boot(dat,name,t,ar,grid,b,c,all,graph)
##  Inputs:  
##  	dat	 data vector (univariate time series)
##  	name	 name of time series, used for printed results and figures
##  	t	 trend order.  0 for no trend, 1 for constant, 2 for constant and trend
##  	ar	 autoregressive order
##  	grid	 number of gridpoints 
##  	b	 number of bootstrap replications at each gridpoint
##  	c	 level of confidence set (e.g., set c=.9 for a 90% region)
##  	all	 1 to compute confidence intervals for all AR coefficients
##  		 0 to compute confidence interval just for coefficient on Y(-1)
##  	graph	 Graph display.  0 for no graph.  1 for graph
##  
##  Note: (1) The program calls the procedures grid_boot
##            which is contained in a separate ASCII file.
##        (2) Package "pracma" is required. Run the following command in R first: 
##            install.packages("pracma")
##
##  There are no outputs.  All results are printed to the screen
##  
##  If you have questions, please contact me at
##  
##  Bruce E. Hansen
##  Department of Economics
##  Social Science Building
##  University of Wisconsin
##  Madison, WI 53706-1393
##  behansen@wisc.edu
##  
#########################################################################

library("pracma")
source ("grid_boot.R")

np <- as.matrix(read.table("np_index.dat"))  
dat <- as.matrix(read.table("nplosser.dat"))  

orig <- 2    # set to 1 for original data, set to 2 for extended data #
t <- 2
grph <- 0    # set to 1 to display graphs #
all <- 0     # set to 1 to compute all confidence intervals #
grid <- 200
bq <- 1999
c <- .9
datname <- rbind("cpi","employmt","gnpdefl","nomgnp","interest",
                 "indprod","gnpperca","realgnp","wages","realwag",
                 "s&p500","unemploy","velocity")

for (i in 1:13){
  d <- np[i,]
  if (orig==1){
    y <- as.matrix(dat[d[1]:(d[2]-18)])
    name <- paste("Nelson-Plosser",datname[i])
    if (i==4) y <- y[21:82]
  }else{
    y <- as.matrix(dat[d[1]:d[2]])
    name <- paste("Extended Nelson-Plosser",datname[i])
  }
  ar <- d[3]
  out <- grid_boot(y,name,t,ar,grid,bq,c,all,grph)
}



